/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package cz.cvut.kbss.ejaspringapp.bo;

import cz.cvut.kbss.ejaspringapp.dto.UserDTO;
import cz.cvut.kbss.ejaspringapp.provider.HashProvider;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Configurable;

/**
 * User business object
 * @author mickapa1
 */
@Configurable(preConstruction=true) // Trida bude instrumentovana a bude mozne do ni injektovat (preconstruction zajisti, ze injektovane property budou pouzitelne jiz v konstruktoru)
@Entity
@Table(name="users")
public class User extends AbstractBusinessObject{
    @Column(length=40, nullable=false)
    private String password;
    @Column(length=40, nullable=false)
    private String salt;
    @Column(nullable=false, unique=true)
    private String username;
    @Column
    private String name;
    @Column
    private String surname;
    
    @Autowired
    private transient HashProvider provider;

    /**
     * Creates user - when using this constructor make sure that salt in initialized before
     */
    public User() {
    }

    /**
     * Creates user with specified password, salt will be automatically generated
     * @param password
     * @param username
     * @param name
     * @param surname 
     */
    public User(String username, String name, String surname, String password) {
        this.salt = provider.computeHash(System.currentTimeMillis() + "");
        setPassword(password);
        this.username = username;
        this.name = name;
        this.surname = surname;
    }

    public User(UserDTO dto, String password){
        this(dto.getUsername(), dto.getName(), dto.getSurname(), password);
    }
    
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = provider.computeHash(password + salt + "140f719caed134b571a857d72c5ca251072e7c3b");
    }

    public String getSalt() {
        return salt;
    }

    public void setSalt(String salt) {
        this.salt = salt;
    }

    public String getSurname() {
        return surname;
    }

    public void setSurname(String surname) {
        this.surname = surname;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }
}
